<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>IsometricProjection</name>
    <message>
        <location filename="../IsometricProjection.js" line="+49"/>
        <source>&amp;Isometric Projection</source>
        <translation>Rzutowanie &amp;izometryczne</translation>
    </message>
</context>
</TS>
